import extra_data


class Gotthard2Ctrl():
    def __init__(
        self,
        run_dc: extra_data.DataCollection,
        ctrl_src: str,
    ):
        """Read slow data.
        :param run_dir: EXtra-data RunDirectory DataCollection object.
        :param ctrl_src: Control source name for accessing slow data.
        """
        self.run_dc = run_dc
        self.ctrl_src = ctrl_src

    def get_bias_voltage(self):
        """Get bias voltage for gotthard2."""
        return self.run_dc[self.ctrl_src, "highVoltageMax"].as_single_value()

    def get_exposure_time(self):
        """Get exposure time for gotthard2."""
        return round(
            self.run_dc[self.ctrl_src, "exposureTime"].as_single_value(), 4)

    def get_exposure_period(self):
        """Get exposure period for gotthard2."""
        return round(
            self.run_dc[self.ctrl_src, "exposurePeriod"].as_single_value(), 4)

    def get_acquisition_rate(self):
        """Get acquisition rate for gotthard2."""
        try:
            return float(
                self.run_dc.get_run_value(self.ctrl_src, "acquisitionRate"))
        except extra_data.PropertyNameError:
            pass

    def get_single_photon(self):
        """Get single photon for gotthard2."""
        if "singlePhoton.value" in self.run_dc.keys_for_source(self.ctrl_src):
            return bool(
                self.run_dc[self.ctrl_src, "singlePhoton"].as_single_value())

    def get_det_type(self):
        """GH2 rxHostname is a vector of bytes objects.
        GH2 25um has two host names unlike 50um which has one.

        Returns:
            str: return if its a 25um or 50um detector.
        """

        hostname = self.run_dc.get_run_value(self.ctrl_src, "rxHostname")
        return "25um" if hostname[1].decode("utf-8") else "50um"
